{{ '{%' }}- extends config.BASE_TEMPLATE {{ '%}' }}
{{ '{%' }}- set title = _("Search results") ~ " | " ~ _("{{cookiecutter.app_name}}") {{ '%}' }}

{{ '{%' }}- block javascript {{ '%}' }}
    {{ '{{' }} super() {{ '}}' }}
    {{ '{{' }} webpack['{{cookiecutter.app_package}}_components.js']{{ '}}' }}
    {{ '{{' }} webpack['{{cookiecutter.app_package}}_components.css']{{ '}}' }}
    {{ '{{' }} webpack['{{cookiecutter.app_package}}_search.js'] {{ '}}' }}
{{ '{%' }}- endblock {{ '%}' }}

{{ '{%' }}- block page_body {{ '%}' }}
<div class="ui main container">
  <div data-invenio-search-config='{{ "{{" }} search_app_config(app_id="{{cookiecutter.app_package|title}}.Search") | tojson {{ "}}" }}'></div>
</div>
{{ '{%' }}- endblock page_body {{ '%}' }}
