/*******************************
            Theme
*******************************/

/*
  The type is the type of the component as defined in semantic-ui - element, collection, view, module
  For simple component, 'element' is the correct type
*/
@type    : 'element';

/*
  This is the name of the component - though not required, keep it the same as the filename
*/
@element : 'sample';

/*******************************

    DO NOT FORGET !!!

Edit *theme.config* in your site 
and add (replace 'sample' with the
name of the component from above)

@sample : 'default';


Edit *theme.less* in your site 
and add the imports for your component
library there. See the commented out
chunks for details.

*******************************/


@import (multiple) '../../theme.config';

/*
  This is the styling of your component. The class should start with .ui.<component-name>

  Note: use variables here, not the exact values. Placing the values to another file (sample.variables)
  will allow users to override these values.
 */
.ui.sample {
    color: @sampleColor;
}

/*
  This will load the overrides, enabling the user of your component to override your css if required
 */
.loadUIOverrides();