/*
 * In this file you will import the less files for your component. 

 The file name of the component is sample.less, note that the extension is not written here.
*/
/*
 & { @import "./definitions/sample"; }
*/
