NRP_CLI_VERSION = "oarepo-cli>=11.0.8,<12"
OAREPO_VERSION = "oarepo>=11,<12"
PYTHON_VERSION = ">=3.9,<3.11"

NR_METADATA_VERSION = ">=1.0.0,<2"
NR_OAIPMH_HARVESTERS_VERSION = ">=1.0.0,<2"
NR_VOCABULARIES_VERSION = ">=1.0.0,<2"

OAREPO_MODEL_BUILDER_CF_VERSION = "==4.*"
OAREPO_MODEL_BUILDER_FILES_VERSION = "==4.*"
OAREPO_MODEL_BUILDER_NR_VERSION = "==4.*"
OAREPO_MODEL_BUILDER_RELATIONS_VERSION = "==4.*"
OAREPO_MODEL_BUILDER_VOCABULARIES_VERSION = "==4.*"
OAREPO_MODEL_BUILDER_TESTS_VERSION = "==4.*"
OAREPO_MODEL_BUILDER_VERSION = "==4.*"
