{%- raw -%}
    {% set options = [
              {
                "key": "docs",
                "title": _("All document records"),
                "text": _("in") ~ " " ~ _("All document records"),
                "value": "/search",
              }]
    %}
    <!-- you can use url_for("<your app>.search") here -->
    <div class="item p-0 search-bar rel-mr-1">
    <div id="header-search-bar" data-options='{{ options | tojson }}'>
        <div class="ui fluid search">
        <div class="ui icon input">
            <input autocomplete="off" placeholder="{{_("Search")}}..."
                    type="text" tabindex="0" class="prompt" value="">
            <i aria-hidden="true" class="search icon"></i>
        </div>
        </div>
    </div>

    </div>

{%- endraw -%}
